@@ -41,7 +41,7 @@ Key Binding:
 """
 
 
-__version__ = "2.4.11"
+__version__ = "2.4.14"
 __license__ = "MIT"
 __author__ = "Benawi Adha"
 __email__ = "benawiadha@gmail.com"
@@ -66,8 +66,10 @@ from difflib import SequenceMatcher as SM
 
 
 # key bindings
-SCROLL_DOWN = {curses.KEY_DOWN, ord("j")}
-SCROLL_UP = {curses.KEY_UP, ord("k")}
+SCROLL_DOWN = {curses.KEY_DOWN}
+SCROLL_DOWN_J = {ord("j")}
+SCROLL_UP = {curses.KEY_UP}
+SCROLL_UP_K = {ord("k")}
 HALF_DOWN = {4}
 HALF_UP = {21}
 PAGE_DOWN = {curses.KEY_NPAGE, ord("l"), ord(" "), curses.KEY_RIGHT}
@@ -436,11 +438,11 @@ def toc(stdscr, src, index):
         if key_toc in range(48, 58): # i.e., k is a numeral
             countstring = countstring + chr(key_toc)
         else:
-            if key_toc in SCROLL_UP or key_toc in PAGE_UP:
+            if key_toc in SCROLL_UP|SCROLL_UP_K or key_toc in PAGE_UP:
                 index -= count
                 if index < 0:
                     index = 0
-            elif key_toc in SCROLL_DOWN or key_toc in PAGE_DOWN:
+            elif key_toc in SCROLL_DOWN|SCROLL_DOWN_J or key_toc in PAGE_DOWN:
                 index += count
                 if index + 1 >= totlines:
                     index = totlines - 1
@@ -520,9 +522,9 @@ def meta(stdscr, ebook):
     padhi = rows - 5 - Y - 4 + 1
 
     while key_meta not in META|QUIT:
-        if key_meta in SCROLL_UP and y > 0:
+        if key_meta in SCROLL_UP|SCROLL_UP_K and y > 0:
             y -= 1
-        elif key_meta in SCROLL_DOWN and y < totlines - hi + 6:
+        elif key_meta in SCROLL_DOWN|SCROLL_DOWN_J and y < totlines - hi + 6:
             y += 1
         elif key_meta in PAGE_UP:
             y = pgup(y, padhi)
@@ -574,9 +576,9 @@ def help(stdscr):
     padhi = rows - 5 - Y - 4 + 1
 
     while key_help not in HELP|QUIT:
-        if key_help in SCROLL_UP and y > 0:
+        if key_help in SCROLL_UP|SCROLL_UP_K and y > 0:
             y -= 1
-        elif key_help in SCROLL_DOWN and y < totlines - hi + 6:
+        elif key_help in SCROLL_DOWN|SCROLL_DOWN_J and y < totlines - hi + 6:
             y += 1
         elif key_help in PAGE_UP:
             y = pgup(y, padhi)
@@ -672,7 +674,10 @@ def searching(stdscr, pad, src, width, y, ch, tot):
         stat.addstr(0, 7, SEARCHPATTERN)
         stat.refresh()
         while True:
-            ipt = stat.getch()
+            ipt = stat.get_wch()
+            if type(ipt) == str:
+                ipt = ord(ipt)
+
             if ipt == 27:
                 stat.clear()
                 stat.refresh()
@@ -688,7 +693,7 @@ def searching(stdscr, pad, src, width, y, ch, tot):
                 curses.curs_set(0)
                 break
             # TODO: why different behaviour unix dos or win lin
-            elif ipt in {8, curses.KEY_BACKSPACE}:
+            elif ipt in {8, 127, curses.KEY_BACKSPACE}:
                 SEARCHPATTERN = SEARCHPATTERN[:-1]
             elif ipt == curses.KEY_RESIZE:
                 stat.clear()
@@ -914,6 +919,11 @@ def reader(stdscr, ebook, index, width, y, pctg):
                     return -1, width, -rows, None
                 else:
                     y = 0
+            elif k in SCROLL_UP_K:
+                if count > 1:
+                    svline = y - 1
+                if y >= count:
+                    y -= count
             elif k in PAGE_UP:
                 if y == 0 and index != 0:
                     return -1, width, -rows, None
@@ -928,6 +938,11 @@ def reader(stdscr, ebook, index, width, y, pctg):
                     return 1, width, 0, None
                 else:
                     y = totlines - rows
+            elif k in SCROLL_DOWN_J:
+                if count > 1:
+                    svline = y + rows - 1
+                if y + count <= totlines - rows:
+                    y += count
             elif k in PAGE_DOWN:
                 if totlines - y - LINEPRSRV > rows:
                     # y = pgdn(y, totlines, rows, LINEPRSRV, count)
